==> debestia8.3-0.3b1pl2.zip: debestia8.3-0.3b1pl2/data/npc/scripts/boatdotrup.lua <==
local keywordHandler = KeywordHandler:new()
local npcHandler = NpcHandler:new(keywordHandler)
NpcSystem.parseParameters(npcHandler)



-- OTServ event handling functions start
function onCreatureAppear(cid)				npcHandler:onCreatureAppear(cid) end
function onCreatureDisappear(cid) 			npcHandler:onCreatureDisappear(cid) end
function onCreatureSay(cid, type, msg) 	npcHandler:onCreatureSay(cid, type, msg) end
function onThink() 						npcHandler:onThink() end
-- OTServ event handling functions end
function creatureSayCallback(cid, type, msg)
	msg = string.lower(msg)
	if msgcontains(msg, 'zabierz mnie do') or msgcontains(msg, 'bring me to') then
		if getPlayerPzLock(cid) == 1 then
			doPlayerSendTextMessage(cid, MESSAGE_STATUS_CONSOLE_BLUE, "Kapitan statku: Nie plywam z osobami ktore dopiero co walczyly.")
			return true
		end
		if msgcontains(msg, 'pieklo') then
			to_destinationz = {cost = 1000, toPosition = {x=1133, y=1019, z=7}, premium = 0}
		else
			return false
		end
		if(getPlayerPremiumDays(cid) > 0 or to_destinationz.premium == 0) and (getPlayerPzLock(cid) == 0)then
			if(doPlayerRemoveMoney(cid, to_destinationz.cost) == TRUE) then
				doTeleportThing(cid, to_destinationz.toPosition, 0)
				doSendMagicEffect(to_destinationz.toPosition, 10)
			end
		end
	end
	if(npcHandler.focus ~= cid) then
		return false
	end
	storage35001 = getPlayerStorageValue(cid, 35001)
	if storage35001 == -1 then
		if msgcontains(msg, 'kraina') or msgcontains(msg, 'umarlych') or msgcontains(msg, 'podroz') or msgcontains(msg, 'nieumarlych') then
			setPlayerStorageValue(cid, 35001, 0)
			selfSay('Jestem stary i slabo sie trzymam. Przynies mi 10 kosci jesli chcesz ze mna podrozowac.')
		end
	elseif storage35001 == 0 then
		if msgcontains(msg, 'kraina') or msgcontains(msg, 'umarlych') or msgcontains(msg, 'kosci') or msgcontains(msg, 'podroz') or msgcontains(msg, 'nieumarlych') then
			if doPlayerTakeItem(cid, 2230, 10) == LUA_NO_ERROR then
				setPlayerStorageValue(cid, 35001, 1)
				selfSay('Dzieki za kosci. To pozwoli mi jeszcze troche dluzej \'pozyc\'. Gdybys chcial plynac do krainy nieumarlych to powiedz.')
			else
				selfSay('Miales mi przyniesc 10 kosci. Wroc kiedy uzbierasz.')
			end
		end
	elseif storage35001 == 1 then -- tresc dla graczy ktorzy zrobili questa
		if msgcontains(msg, 'kraina') or msgcontains(msg, 'umarlych') or msgcontains(msg, 'podroz') or msgcontains(msg, 'nieumarlych') then
			selfSay("Chcesz poplynac do krainy nieumarlych za 50 zlotych monet?")
			talk_state = 1
		elseif talk_state == 1 then
			if msgcontains(msg, 'yes') or msgcontains(msg, 'tak') then
				if doPlayerRemoveMoney(cid, 50) == TRUE then --tutaj cena za podroz do krainy umarlych
					doTeleportThing(cid, {x=454, y=516, z=7}, 1)
					doSendMagicEffect({x=454, y=516, z=7},10)
					selfSay("Milej podrozy.")
				else
					selfSay("Nie masz dosc pieniedzy.")
				end
			else
				selfSay("Za drogo?")
			end
			talk_state = 0
		end
	end
end
local travelNode = keywordHandler:addKeyword({'piekl'}, StdModule.say, {npcHandler = npcHandler, onlyFocus = true, text = 'Chcesz poplynac do piekla za 1000 zlotych monet??'})
	travelNode:addChildKeyword({'yes'}, StdModule.travel, {npcHandler = npcHandler, premium = true, level = 0, cost = 1000, destination = {x=1133, y=1019, z=7} })
	travelNode:addChildKeyword({'no'}, StdModule.say, {npcHandler = npcHandler, onlyFocus = true, reset = true, text = 'Za drogo? Nie bede ryzykowal pozostania tam na zawsze taniej!'})
	travelNode:addChildKeyword({'tak'}, StdModule.travel, {npcHandler = npcHandler, premium = true, level = 0, cost = 1000, destination = {x=1133, y=1019, z=7} })
	travelNode:addChildKeyword({'nie'}, StdModule.say, {npcHandler = npcHandler, onlyFocus = true, reset = true, text = 'Za drogo? Nie bede ryzykowal pozostania tam na zawsze taniej!'})


npcHandler:setCallback(CALLBACK_MESSAGE_DEFAULT, creatureSayCallback)
-- Makes sure the npc reacts when you say hi, bye etc.
npcHandler:addModule(FocusModule:new())

==> debestia8.4-0.3.1pl2.zip: debestia8.4-0.3.1pl2/data/npc/scripts/boatdotrup.lua <==
local keywordHandler = KeywordHandler:new()
local npcHandler = NpcHandler:new(keywordHandler)
NpcSystem.parseParameters(npcHandler)



-- OTServ event handling functions start
function onCreatureAppear(cid)				npcHandler:onCreatureAppear(cid) end
function onCreatureDisappear(cid) 			npcHandler:onCreatureDisappear(cid) end
function onCreatureSay(cid, type, msg) 	npcHandler:onCreatureSay(cid, type, msg) end
function onThink() 						npcHandler:onThink() end
-- OTServ event handling functions end
function creatureSayCallback(cid, type, msg)
	msg = string.lower(msg)
	if msgcontains(msg, 'zabierz mnie do') or msgcontains(msg, 'bring me to') then
		if (getPlayerPzLock(cid) == 1) then
			doPlayerSendTextMessage(cid, MESSAGE_STATUS_CONSOLE_BLUE, "Nie plywam z osobami tuz po walce. Jeszcze bys mi uszkodzil statek!")
			return true
		end
		if msgcontains(msg, 'pieklo') then
			to_destinationz = {cost = 1000, toPosition = {x=1133, y=1019, z=7}, premium = 0}
		else
			return false
		end
		if(getPlayerPremiumDays(cid) > 0 or to_destinationz.premium == 0) and (getPlayerPzLock(cid) == 0)then
			if(doPlayerRemoveMoney(cid, to_destinationz.cost) == TRUE) then
				doTeleportThing(cid, to_destinationz.toPosition, 0)
				doSendMagicEffect(to_destinationz.toPosition, 10)
			end
		end
	end
	if(npcHandler.focus ~= cid) then
		return false
	end
	storage35001 = getPlayerStorageValue(cid, 35001)
	if storage35001 == -1 then
		if msgcontains(msg, 'kraina') or msgcontains(msg, 'umarlych') or msgcontains(msg, 'podroz') or msgcontains(msg, 'nieumarlych') then
			setPlayerStorageValue(cid, 35001, 0)
			selfSay('Jestem stary i slabo sie trzymam. Przynies mi 10 kosci jesli chcesz ze mna podrozowac.')
		end
	elseif storage35001 == 0 then
		if msgcontains(msg, 'kraina') or msgcontains(msg, 'umarlych') or msgcontains(msg, 'kosci') or msgcontains(msg, 'podroz') or msgcontains(msg, 'nieumarlych') then
			if doPlayerTakeItem(cid, 2230, 10) == LUA_NO_ERROR then
				setPlayerStorageValue(cid, 35001, 1)
				selfSay('Dzieki za kosci. To pozwoli mi jeszcze troche dluzej \'pozyc\'. Gdybys chcial plynac do krainy nieumarlych to powiedz.')
			else
				selfSay('Miales mi przyniesc 10 kosci. Wroc kiedy uzbierasz.')
			end
		end
	elseif storage35001 == 1 then -- tresc dla graczy ktorzy zrobili questa
		if msgcontains(msg, 'kraina') or msgcontains(msg, 'umarlych') or msgcontains(msg, 'podroz') or msgcontains(msg, 'nieumarlych') then
			selfSay("Chcesz poplynac do krainy nieumarlych za 50 zlotych monet?")
			talk_state = 1
		elseif talk_state == 1 then
			if msgcontains(msg, 'yes') or msgcontains(msg, 'tak') then
				if doPlayerRemoveMoney(cid, 50) == TRUE then --tutaj cena za podroz do krainy umarlych
					doTeleportThing(cid, {x=454, y=516, z=7}, 1)
					doSendMagicEffect({x=454, y=516, z=7},10)
					selfSay("Milej podrozy.")
				else
					selfSay("Nie masz dosc pieniedzy.")
				end
			else
				selfSay("Za drogo?")
			end
			talk_state = 0
		end
	end
end
local travelNode = keywordHandler:addKeyword({'piekl'}, StdModule.say, {npcHandler = npcHandler, onlyFocus = true, text = 'Chcesz poplynac do piekla za 1000 zlotych monet??'})
	travelNode:addChildKeyword({'yes'}, StdModule.travel, {npcHandler = npcHandler, premium = true, level = 0, cost = 1000, destination = {x=1133, y=1019, z=7} })
	travelNode:addChildKeyword({'no'}, StdModule.say, {npcHandler = npcHandler, onlyFocus = true, reset = true, text = 'Za drogo? Nie bede ryzykowal pozostania tam na zawsze taniej!'})
	travelNode:addChildKeyword({'tak'}, StdModule.travel, {npcHandler = npcHandler, premium = true, level = 0, cost = 1000, destination = {x=1133, y=1019, z=7} })
	travelNode:addChildKeyword({'nie'}, StdModule.say, {npcHandler = npcHandler, onlyFocus = true, reset = true, text = 'Za drogo? Nie bede ryzykowal pozostania tam na zawsze taniej!'})


npcHandler:setCallback(CALLBACK_MESSAGE_DEFAULT, creatureSayCallback)
-- Makes sure the npc reacts when you say hi, bye etc.
npcHandler:addModule(FocusModule:new())
